==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/request/SolutioncomponentrelationshipconfigurationRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Solutioncomponentrelationshipconfiguration;
import microsoft.dynamics.crm.entity.collection.request.AsyncoperationCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.BulkdeletefailureCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.DuplicaterecordCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.MailboxtrackingfolderCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.PrincipalobjectattributeaccessCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.ProcesssessionCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SyncerrorCollectionRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

@JsonIgnoreType
public class SolutioncomponentrelationshipconfigurationRequest extends EntityRequest<Solutioncomponentrelationshipconfiguration> {

    public SolutioncomponentrelationshipconfigurationRequest(ContextPath contextPath, Optional<Object> value) {
        super(Solutioncomponentrelationshipconfiguration.class, contextPath, SchemaInfo.INSTANCE, value);
    }

    public SystemuserRequest createdby() {
        return new SystemuserRequest(contextPath.addSegment("createdby"), Optional.empty());
    }

    public SystemuserRequest createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("createdonbehalfby"), Optional.empty());
    }

    public SystemuserRequest modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedby"), Optional.empty());
    }

    public SystemuserRequest modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedonbehalfby"), Optional.empty());
    }

    public OrganizationRequest organizationid() {
        return new OrganizationRequest(contextPath.addSegment("organizationid"), Optional.empty());
    }

    public SyncerrorCollectionRequest solutioncomponentrelationshipconfiguration_SyncErrors() {
        return new SyncerrorCollectionRequest(
                        contextPath.addSegment("solutioncomponentrelationshipconfiguration_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest solutioncomponentrelationshipconfiguration_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("solutioncomponentrelationshipconfiguration_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest solutioncomponentrelationshipconfiguration_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(
                        contextPath.addSegment("solutioncomponentrelationshipconfiguration_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest solutioncomponentrelationshipconfiguration_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("solutioncomponentrelationshipconfiguration_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest solutioncomponentrelationshipconfiguration_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(
                        contextPath.addSegment("solutioncomponentrelationshipconfiguration_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest solutioncomponentrelationshipconfiguration_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("solutioncomponentrelationshipconfiguration_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest solutioncomponentrelationshipconfiguration_AsyncOperations() {
        return new AsyncoperationCollectionRequest(
                        contextPath.addSegment("solutioncomponentrelationshipconfiguration_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest solutioncomponentrelationshipconfiguration_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("solutioncomponentrelationshipconfiguration_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest solutioncomponentrelationshipconfiguration_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(
                        contextPath.addSegment("solutioncomponentrelationshipconfiguration_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest solutioncomponentrelationshipconfiguration_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("solutioncomponentrelationshipconfiguration_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest solutioncomponentrelationshipconfiguration_ProcessSession() {
        return new ProcesssessionCollectionRequest(
                        contextPath.addSegment("solutioncomponentrelationshipconfiguration_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest solutioncomponentrelationshipconfiguration_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("solutioncomponentrelationshipconfiguration_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest solutioncomponentrelationshipconfiguration_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(
                        contextPath.addSegment("solutioncomponentrelationshipconfiguration_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest solutioncomponentrelationshipconfiguration_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("solutioncomponentrelationshipconfiguration_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest solutioncomponentrelationshipconfiguration_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(
                        contextPath.addSegment("solutioncomponentrelationshipconfiguration_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest solutioncomponentrelationshipconfiguration_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("solutioncomponentrelationshipconfiguration_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public EntityrelationshipRequest entityRelationshipId() {
        return new EntityrelationshipRequest(contextPath.addSegment("EntityRelationshipId"), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.49-sources.jar: microsoft/dynamics/crm/entity/request/SolutioncomponentrelationshipconfigurationRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Solutioncomponentrelationshipconfiguration;
import microsoft.dynamics.crm.entity.collection.request.AsyncoperationCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.BulkdeletefailureCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.DuplicaterecordCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.MailboxtrackingfolderCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.PrincipalobjectattributeaccessCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.ProcesssessionCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SyncerrorCollectionRequest;

@JsonIgnoreType
public class SolutioncomponentrelationshipconfigurationRequest extends EntityRequest<Solutioncomponentrelationshipconfiguration> {

    public SolutioncomponentrelationshipconfigurationRequest(ContextPath contextPath, Optional<Object> value) {
        super(Solutioncomponentrelationshipconfiguration.class, contextPath, value);
    }

    public SystemuserRequest createdby() {
        return new SystemuserRequest(contextPath.addSegment("createdby"), Optional.empty());
    }

    public SystemuserRequest createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("createdonbehalfby"), Optional.empty());
    }

    public SystemuserRequest modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedby"), Optional.empty());
    }

    public SystemuserRequest modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedonbehalfby"), Optional.empty());
    }

    public OrganizationRequest organizationid() {
        return new OrganizationRequest(contextPath.addSegment("organizationid"), Optional.empty());
    }

    public SyncerrorCollectionRequest solutioncomponentrelationshipconfiguration_SyncErrors() {
        return new SyncerrorCollectionRequest(
                        contextPath.addSegment("solutioncomponentrelationshipconfiguration_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest solutioncomponentrelationshipconfiguration_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("solutioncomponentrelationshipconfiguration_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest solutioncomponentrelationshipconfiguration_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(
                        contextPath.addSegment("solutioncomponentrelationshipconfiguration_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest solutioncomponentrelationshipconfiguration_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("solutioncomponentrelationshipconfiguration_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest solutioncomponentrelationshipconfiguration_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(
                        contextPath.addSegment("solutioncomponentrelationshipconfiguration_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest solutioncomponentrelationshipconfiguration_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("solutioncomponentrelationshipconfiguration_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest solutioncomponentrelationshipconfiguration_AsyncOperations() {
        return new AsyncoperationCollectionRequest(
                        contextPath.addSegment("solutioncomponentrelationshipconfiguration_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest solutioncomponentrelationshipconfiguration_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("solutioncomponentrelationshipconfiguration_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest solutioncomponentrelationshipconfiguration_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(
                        contextPath.addSegment("solutioncomponentrelationshipconfiguration_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest solutioncomponentrelationshipconfiguration_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("solutioncomponentrelationshipconfiguration_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest solutioncomponentrelationshipconfiguration_ProcessSession() {
        return new ProcesssessionCollectionRequest(
                        contextPath.addSegment("solutioncomponentrelationshipconfiguration_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest solutioncomponentrelationshipconfiguration_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("solutioncomponentrelationshipconfiguration_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest solutioncomponentrelationshipconfiguration_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(
                        contextPath.addSegment("solutioncomponentrelationshipconfiguration_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest solutioncomponentrelationshipconfiguration_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("solutioncomponentrelationshipconfiguration_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest solutioncomponentrelationshipconfiguration_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(
                        contextPath.addSegment("solutioncomponentrelationshipconfiguration_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest solutioncomponentrelationshipconfiguration_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("solutioncomponentrelationshipconfiguration_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public EntityrelationshipRequest entityRelationshipId() {
        return new EntityrelationshipRequest(contextPath.addSegment("EntityRelationshipId"), Optional.empty());
    }

}
